# Trim or Edit Current Conversation

Toolmate AI v0.4.82+ supports trimming or editing the current conversation.

With trimming, you may remove unwanted items or reduce token cost.

With editing, you can fine tune the message chain in the current conversation.

# How?

Select `trim current conversation` or `edit current conversation` from action menu.

Alternately, enter `.trim` or `.edit` in ToolMate AI prompt.

![change_current](https://github.com/user-attachments/assets/a5d5ec96-034b-4835-9580-c640b0140453)

# Example - Trimming

![trim01](https://github.com/user-attachments/assets/3643e124-a849-4a54-bc9b-336beea6a19b)

![trim02](https://github.com/user-attachments/assets/aef84676-0c37-4c79-994c-6e381be48f86)

![trim03](https://github.com/user-attachments/assets/2874f6ba-81ba-4384-8e2d-2cda9d80bd35)

# Example - Editing

![edit01](https://github.com/user-attachments/assets/8ecc8082-a849-425d-8265-8485c541a9f0)

![edit02](https://github.com/user-attachments/assets/d7f78a81-cd8b-48af-a374-cc398b3d2905)

![edit03](https://github.com/user-attachments/assets/e69f246f-0f5d-4d8f-ba1d-3336ca4a4fd7)

![edit04](https://github.com/user-attachments/assets/8fc3ef54-1d67-4e42-9ae7-d49f8d5cd7c3)

![edit05](https://github.com/user-attachments/assets/ae7d2f4a-14c4-47b8-963a-e821416b085b)
